@@ -1,10 +1,11 @@
-import yaml
 import os
+import yaml
 from configurators import *
 
 
+CONFIG = {}
 # first the lowest-level configs are merged with these defaults.
-CONFIG = {
+defaults = {
     'project_path': os.getcwd(),
     'site_path': u'site/',
     'deploy_path': u'public/',
@@ -12,6 +13,11 @@ CONFIG = {
     'dont_remove': ['.*'],
     'config_file': u'config.yaml',
     'html_extension': u'.html',
+
+    ##|  HOOKS
+    'config_hook': None,
+
+    ##|  EXTENSIONS
     'extensions': [],
     'filters': {},
     'processors': [],
@@ -32,6 +38,8 @@ CONFIG = {
         title_from_name,
     ],
 }
+defaults.update(CONFIG)
+CONFIG.update(defaults)
 
 # this can change per folder, but please don't, that's just weird.
 html_ext = CONFIG['html_extension']
@@ -40,13 +48,12 @@ more_defaults = {
     'host': 'http://localhost:8000',
     'index': 'index' + html_ext,
     'rename_extensions': {
-        '.md': html_ext,
         '.j2': html_ext,
         '.jinja2': html_ext,
     },
     'ignore': [
         '.*',
-        CONFIG['config_file']
+        CONFIG['config_file'],
     ],
     'dont_process': [
         '*.js', '*.css',
@@ -63,7 +70,14 @@ more_defaults = {
     ]
 }
 more_defaults.update(CONFIG)
-CONFIG = more_defaults
+CONFIG.update(more_defaults)
+
+# normalize paths
+for conf in ['project_path', 'site_path', 'deploy_path']:
+    if CONFIG[conf][0] == '~':
+        CONFIG[conf] = os.path.expanduser(CONFIG[conf])
+    elif CONFIG[conf][0] == '.':
+        CONFIG[conf] = os.path.abspath(CONFIG[conf])
 
 # now we can look for the app config
 config_path = os.path.join(CONFIG['project_path'], CONFIG['config_file'])
